==> v3.1.tar.gz: grub-themes/README.md <==
# Distro Grub Themes

[![name](https://img.shields.io/github/license/AdisonCavani/distro-grub-themes)](https://github.com/AdisonCavani/distro-grub-themes/blob/master/LICENSE)
[![name](https://img.shields.io/github/v/release/AdisonCavani/distro-grub-themes)](https://github.com/AdisonCavani/distro-grub-themes/releases)
[![Build](https://github.com/AdisonCavani/distro-grub-themes/actions/workflows/update-content.yml/badge.svg?event=push)](https://github.com/AdisonCavani/distro-grub-themes/actions/workflows/update-content.yml)
<br>

A pack of GRUB2 themes for different Linux distributions and OSs.<br>
It aims to replace the default GRUB look, with a nice and colorful theme.

## Get started

Documentation is available at [k1ng.dev/distro-grub-themes](https://k1ng.dev/distro-grub-themes).  
Raw markdown files are located in [`/docs`](./docs) folder.

## Funding
I put a lot of effort and my free time into maintaining this project.  
If you appreciate that, you can buy me a coffee.

[<img src="https://www.buymeacoffee.com/assets/img/guidelines/download-assets-sm-1.svg" alt="Buy Me A Coffee" height="50px" />](https://www.buymeacoffee.com/adisoncavani)

## Contributing

Development happens in the open on GitHub, and we are grateful to the community for contributing bugfixes and improvements.  
Read below to learn how you can take part in improving it.

### Code of Conduct

This project has adopted a Code of Conduct that we expect project participants to adhere to.  
Please read [the full text](https://github.com/AdisonCavani/distro-grub-themes/blob/master/.github/CODE_OF_CONDUCT.md) so that you can understand what actions will and will not be tolerated.

### Contributing Guide

Read [contributing guide](https://github.com/AdisonCavani/distro-grub-themes/blob/master/CONTRIBUTING.md) to learn how to propose changes, bugfixes and improvements.

### License
This project is licensed under [GNU General Public License v3.0](https://github.com/AdisonCavani/distro-grub-themes/blob/master/LICENSE)

### Contributors

Thank you to all the people who already contributed to this project!

<a href="https://github.com/AdisonCavani/distro-grub-themes/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=AdisonCavani/distro-grub-themes" />
</a>

==> v3.2.tar.gz: grub-themes/README.md <==
# Distro Grub Themes

[![name](https://img.shields.io/github/license/AdisonCavani/distro-grub-themes)](https://github.com/AdisonCavani/distro-grub-themes/blob/master/LICENSE)
[![name](https://img.shields.io/github/v/release/AdisonCavani/distro-grub-themes)](https://github.com/AdisonCavani/distro-grub-themes/releases)
[![Build](https://github.com/AdisonCavani/distro-grub-themes/actions/workflows/update-content.yml/badge.svg?event=push)](https://github.com/AdisonCavani/distro-grub-themes/actions/workflows/update-content.yml)
<br>

A pack of GRUB2 themes for different Linux distributions and OSs.<br>
It aims to replace the default GRUB look, with a nice and colorful theme.

## Get started

- **Theme preview** is available at [k1ng.dev/distro-grub-themes/preview](https://k1ng.dev/distro-grub-themes/preview).  
- **Documentation** is available at [k1ng.dev/distro-grub-themes](https://k1ng.dev/distro-grub-themes).  
- Raw markdown files are located in [`/docs`](./docs) folder.

## Funding
I put a lot of effort and my free time into maintaining this project.  
If you appreciate that, you can buy me a coffee.

[<img src="https://www.buymeacoffee.com/assets/img/guidelines/download-assets-sm-1.svg" alt="Buy Me A Coffee" height="50px" />](https://www.buymeacoffee.com/adisoncavani)

## Contributing

Development happens in the open on GitHub, and we are grateful to the community for contributing bugfixes and improvements.  
Read below to learn how you can take part in improving it.

### Code of Conduct

This project has adopted a Code of Conduct that we expect project participants to adhere to.  
Please read [the full text](https://github.com/AdisonCavani/distro-grub-themes/blob/master/.github/CODE_OF_CONDUCT.md) so that you can understand what actions will and will not be tolerated.

### Contributing Guide

Read [contributing guide](https://github.com/AdisonCavani/distro-grub-themes/blob/master/CONTRIBUTING.md) to learn how to propose changes, bugfixes and improvements.

### License
This project is licensed under [GNU General Public License v3.0](https://github.com/AdisonCavani/distro-grub-themes/blob/master/LICENSE)

### Contributors

Thank you to all the people who already contributed to this project!

<a href="https://github.com/AdisonCavani/distro-grub-themes/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=AdisonCavani/distro-grub-themes" />
</a>
